@@ -6,12 +6,12 @@
 poetry run nox -l
 poetry run nox --list-sessions
 
-poetry run nox -s build_check-3.9 build_dist-3.9 check_safety-3.9
-poetry run nox --session check_safety-3.9
+poetry run nox -s build_check-3.9 build_dist-3.9 coverage-3.9
+poetry run nox --session coverage-3.9
 
 poetry run nox --python 3.8
 
-poetry run nox -k "not tests and not check_safety"
+poetry run nox -k "not tests and not coverage"
 ```
 
 Useful nox snippets
@@ -32,7 +32,6 @@ with open(path_stdout, 'w') as out:
 
 """
 
-import json
 import re
 import shlex
 from contextlib import suppress
@@ -44,7 +43,7 @@ from beartype import beartype
 from beartype.typing import Callable, Dict, List
 from loguru import logger
 
-from ..doit_tasks.doit_globals import DG, DoitAction, DoitTask
+from ..doit_tasks.doit_globals import DoitAction, DoitTask, get_dg
 from ..doit_tasks.test import task_coverage, task_test
 from ..file_helpers import if_found_unlink
 
@@ -97,7 +96,7 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
             extras: list of extras to install
 
         """
-        if DG.meta.pkg_name == 'calcipy':
+        if get_dg().meta.pkg_name == 'calcipy':
             session.poetry.installroot(extras=extras)
         else:  # pragma: no cover
             session.install('.', f'calcipy[{",".join(extras)}]')
@@ -152,7 +151,7 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
             else:
                 raise NotImplementedError(f'Unable to run {action} ({type(action)})')
 
-    @nox_session(python=DG.test.pythons, reuse_venv=True)
+    @nox_session(python=get_dg().test.pythons, reuse_venv=True)
     def tests(session: Session) -> None:
         """Run doit test task for specified python versions.
 
@@ -164,7 +163,7 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
         _install_pinned(session, key=_DEV_KEY)
         _run_doit_task(session, task_test)
 
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=True)
+    @nox_session(python=get_dg().test.pythons[-1:], reuse_venv=True)
     def coverage(session: Session) -> None:
         """Run doit test task for specified python versions.
 
@@ -176,7 +175,7 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
         _install_pinned(session, key=_DEV_KEY)
         _run_doit_task(session, task_coverage)
 
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=False)
+    @nox_session(python=get_dg().test.pythons[-1:], reuse_venv=False)
     def build_dist(session: Session) -> None:
         """Build the project files within a controlled environment for repeatability.
 
@@ -184,14 +183,14 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
             session: nox_poetry Session
 
         """
-        if_found_unlink(DG.meta.path_project / 'dist')
+        if_found_unlink(get_dg().meta.path_project / 'dist')
         path_wheel = session.poetry.build_package()
         logger.info(f'Created wheel: {path_wheel}')
         # Install the wheel and check that imports without any of the optional dependencies
         session.install(path_wheel)
         session.run(*shlex.split('python scripts/check_imports.py'), stdout=True)
 
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=True)
+    @nox_session(python=get_dg().test.pythons[-1:], reuse_venv=True)
     def build_check(session: Session) -> None:
         """Check that the built output meets all checks.
 
@@ -209,70 +208,8 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
         session.install('poetry>=1.2.0b3')  # required for "poetry.core.masonry.api" build backend
         session.run('pyroma', '--file', path_sdist.as_posix(), '--min=9', stdout=True)
 
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=True)
-    def check_safety(session: Session) -> None:
-        """Check for known vulnerabilities with safety.
-
-        Based on: https://github.com/pyupio/safety/issues/201#issuecomment-632627366
-
-        Args:
-            session: nox_poetry Session
-
-        Raises:
-            RuntimeError: if safety exited with errors, but not caught by session
-
-        """
-        session.install('safety>=2.1.1', '--upgrade')
-        path_requirements = session.poetry.export_requirements().resolve()
-        path_report = Path('insecure_report.json').resolve()
-        logger.info(f'Creating safety report: {path_report}')
-        session.run(*shlex.split(f'safety check --file {path_requirements} --save-json {path_report}'), stdout=True)
-        report_data = json.loads(path_report.read_text())
-        if report_data['vulnerabilities']:
-            raise RuntimeError(f'Found safety warnings in {path_report}: {report_data}')
-        path_report.unlink()
-
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=True)
-    def check_security(session: Session) -> None:
-        """More general checks for common security issues.
-
-        Args:
-            session: nox_poetry Session
-
-        """
-        session.install('semgrep>=0.106.0', '--upgrade')  # Runs "safety" and other tools
-        allow_py_rules = '--dangerously-allow-arbitrary-code-execution-from-rules'
-        # TODO: Implement semgrep - what are a good ruleset to start with? Currently only a nox-session (no doit task)
-        #   https://github.com/returntocorp/semgrep-rules/tree/develop/python
-        #   https://awesomeopensource.com/project/returntocorp/semgrep-rules?categorypage=45
-        configs = ' '.join([
-            # See more at: https://semgrep.dev/explore
-            '--config=p/ci',
-            '--config=p/security-audit',
-            '--config=r/python.airflow',
-            '--config=r/python.attr',
-            '--config=r/python.click',
-            '--config=r/python.cryptography',
-            '--config=r/python.distributed',
-            '--config=r/python.docker',
-            '--config=r/python.flask',
-            '--config=r/python.jinja2',
-            '--config=r/python.jwt',
-            '--config=r/python.lang',
-            '--config=r/python.pycryptodome',
-            '--config=r/python.requests',
-            '--config=r/python.security',
-            '--config=r/python.sh',
-            '--config=r/python.sqlalchemy',
-            # dlukeomalley:unchecked-subprocess-call
-            # dlukeomalley:use-assertEqual-for-equality
-            # dlukeomalley:flask-set-cookie
-            # clintgibler:no-exec
-        ])
-        session.run(*shlex.split(f'semgrep {DG.meta.pkg_name} {allow_py_rules} {configs}'), stdout=True)
-
     # TODO: https://github.com/tonybaloney/wily/blob/e72b7d95228bbe5538a072dc5d1186daa318bb03/src/wily/__main__.py#L261
-    @nox_session(python=DG.test.pythons[-1:], reuse_venv=True)
+    @nox_session(python=get_dg().test.pythons[-1:], reuse_venv=True)
     def check_wily(session: Session) -> None:
         """Run `wily` separately because of dependency constraints.
 
@@ -288,14 +225,15 @@ if _HAS_TEST_IMPORTS:  # pragma: no cover  # noqa: C901
         #     'raw.loc', 'raw.lloc', 'raw.sloc', 'maintainability.rank', 'maintainability.mi', 'cyclomatic.complexity',
         #     'halstead.h1', 'halstead.vocabulary', 'halstead.length', 'halstead.volume', 'halstead.difficulty', 'halstead.effort',
         # ])
+        dg = get_dg()
         build_args = '--max-revisions 50'
-        report_args = f'--output {DG.meta.path_project}/report.txt --message --number 50'
+        report_args = f'--output {dg.meta.path_project}/report.txt --message --number 50'
         with suppress(Exception):
-            session.run(*shlex.split(f'wily build {DG.meta.pkg_name} {build_args}'), stdout=True)
-            session.run(*shlex.split(f'wily report {DG.meta.pkg_name} {report_args}'), stdout=True)
+            session.run(*shlex.split(f'wily build {dg.meta.pkg_name} {build_args}'), stdout=True)
+            session.run(*shlex.split(f'wily report {dg.meta.pkg_name} {report_args}'), stdout=True)
 
             # FYI: Opens plotly graph in web browser and not necessary to run "wily" again
             # metric = 'raw.loc'  # 'cyclomatic.complexity' 'maintainability.mi' 'halstead.h1'
-            # session.run(*shlex.split(f'wily graph {DG.meta.pkg_name} {metric}'), stdout=True)
+            # session.run(*shlex.split(f'wily graph {dg.meta.pkg_name} {metric}'), stdout=True)
 
         # TODO: Could use file archiver instead of git when the above fails?
