@@ -5,16 +5,18 @@ import re
 import warnings
 from functools import partial
 from pathlib import Path
+from typing import ClassVar
+from uuid import uuid4
 
 import doit
 import tomli
-from attrs import field, mutable
-from attrs_strict import type_validator
 from beartype import beartype
 from beartype.typing import Any, Callable, Dict, Iterable, List, Optional, Pattern, Set, Tuple, Union
 from doit.action import BaseAction
 from doit.task import Task
 from loguru import logger
+from pydantic import BaseModel, Field
+from pydantic.dataclasses import dataclass
 
 from ..code_tag_collector import CODE_TAG_RE, COMMON_CODE_TAGS
 from ..file_helpers import _MKDOCS_CONFIG_NAME, _read_yaml_file, get_doc_dir
@@ -30,12 +32,13 @@ _DoitCallableArgs = Iterable[Union[str, float, int, Path, Dict[str, Any]]]
 DoitAction = Union[str, BaseAction, Tuple[Callable, _DoitCallableArgs]]  # type: ignore[type-arg]
 """Type: individual doit action."""
 
+# TODO: Better differentiate Task vs. Dict when typing and a dictionary is expected
 DoitTask = Union[Task, Dict[str, DoitAction]]
 """Type: full doit task."""
 
 
 @beartype
-def _make_full_path(raw: Union[Path, str], path_base: Path) -> Path:
+def _make_full_path(raw: Union[Path, str], *, path_base: Path) -> Path:
     """Return a full path by determining if the source path is an absolute path. If not combines with base path.
 
     Args:
@@ -64,23 +67,20 @@ def _member_filter(member: Any, instance_type: Any) -> bool:
     return instance_type is None or isinstance(member, instance_type)
 
 
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class _PathAttrBase:
 
-    path_project: Path = field(validator=type_validator())
+    path_project: Path
     """Path to the package directory."""
 
-    def __attrs_post_init__(self) -> None:
+    def __post_init__(self) -> None:
         """Initialize full paths with the package base directory if necessary.
 
         Raises:
             RuntimeError: if any paths are None
 
         """
-        if self.path_project is None:
-            raise RuntimeError('Missing keyword argument "path_project"')  # pragma: no cover
         self._resolve_class_paths(self.path_project)
-        self._verify_initialized_paths()
 
     @beartype
     def _get_members(self, prefix: Optional[str], **kwargs: Any) -> List[Tuple[str, Any]]:
@@ -113,49 +113,37 @@ class _PathAttrBase:
 
         """
         for name, path_raw in self._get_members(instance_type=type(Path()), prefix=None):
-            if not path_raw.is_absolute():  # type: ignore[attr-defined]
+            if not path_raw.is_absolute():
                 setattr(self, name, base_path / path_raw)  # type: ignore[operator]
                 logger.debug(f'Mutated: self.{name}={path_raw} (now: {getattr(self, name)})')
 
-    @beartype
-    def _verify_initialized_paths(self) -> None:
-        """Verify that all paths are not None.
 
-        WARN: will not raise on error the class attribute
-
-        Raises:
-            RuntimeError: if any paths are None
-
-        """
-        missing = [name for name, _m in self._get_members(instance_type=type(None), prefix='path_')]
-        if missing:
-            kwargs = ', '.join(missing)
-            raise RuntimeError(f'Missing keyword arguments for: {kwargs}')
-
-
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class PackageMeta(_PathAttrBase):
     """Package Meta-Information."""
 
-    path_toml: Path = field(validator=type_validator(), default=Path('pyproject.toml'))
-    """Relative path to the poetry toml file."""
-
-    ignore_patterns: List[str] = field(validator=type_validator(), factory=list)
+    ignore_patterns: List[str] = Field(default_factory=list)
     """List of glob patterns to ignore from all analysis."""
 
-    paths: List[Path] = field(validator=type_validator(), init=False)
+    paths: ClassVar[List[Path]]
     """Paths to all tracked files that were not ignored with specified patterns `find_project_files`."""
 
-    paths_by_suffix: Dict[str, List[Path]] = field(validator=type_validator(), init=False)
-    """Paths to all tracked files that were not ignored with specified patterns `find_project_files_by_suffix`."""
+    path_toml: ClassVar[Path]
+    """Path to the poetry toml file."""
 
-    pkg_name: str = field(validator=type_validator(), init=False)
+    pkg_name: ClassVar[str]
     """Package string name."""
 
-    pkg_version: str = field(validator=type_validator(), init=False)
+    pkg_version: ClassVar[str]
     """Package version."""
 
-    def __attrs_post_init__(self) -> None:
+    min_pyhon: ClassVar[Tuple[str]]
+    """Minimum Python version from pyproject.toml file."""
+
+    paths_by_suffix: ClassVar[Dict[str, List[Path]]]
+    """Paths to all tracked files that were not ignored with specified patterns `find_project_files_by_suffix`."""
+
+    def __post_init__(self) -> None:
         """Finish initializing class attributes.
 
         Raises:
@@ -163,18 +151,23 @@ class PackageMeta(_PathAttrBase):
             FileNotFoundError: if the toml could not be located
 
         """
-        super().__attrs_post_init__()
+        super().__post_init__()
 
         # Note: toml is an optional dependency required only when using the `doit_tasks` in development
         if tomli is None:  # pragma: no cover
             raise RuntimeError(_DOIT_TASK_IMPORT_ERROR)
 
+        self.path_toml = self.path_project / 'pyproject.toml'
         if not self.path_toml.is_file():
-            raise RuntimeError(f'Check "{self.path_project}". Could not find: "{self.path_toml}"')
+            raise RuntimeError(f'Check "path_project". Could not find: "{self.path_toml}"')
 
         poetry_config = tomli.loads(self.path_toml.read_text())['tool']['poetry']
         self.pkg_name = poetry_config['name']
         self.pkg_version = poetry_config['version']
+        py_constraint = poetry_config['dependencies']['python']
+        self.min_python = py_constraint.split(',')[0].lstrip('^>=').split('.')
+        if len(self.min_python) != 3 and self.min_python[0] != '3':
+            raise ValueError(f'Could not parse a valid minimum Python 3 version from {py_constraint}')
 
         if '-' in self.pkg_name:  # pragma: no cover
             warnings.warn(f'Replace dashes in name with underscores ({self.pkg_name}) in {self.path_toml}')
@@ -183,19 +176,19 @@ class PackageMeta(_PathAttrBase):
         self.paths_by_suffix = find_project_files_by_suffix(self.path_project, self.ignore_patterns)
 
     @beartype
-    def __shorted_path_list(self) -> Set[str]:  # pragma: no cover
+    def _shorten_path_lists(self) -> Set[Path]:
         """Shorten the list of directories common to the specified paths.
 
-        > Not currently needed, but could be useful
+        > FYI: Not currently needed, but could be useful
 
         Returns:
-            Set[str]: set of most common top-level directories relative to the project dir
+            Set[Path]: set of unique paths relative to project
 
         """
         return {
-            pth.parent.relative_to(self.path_project).as_posix()
+            pth.parent.relative_to(self.path_project)
             for pth in self.paths
-        }  # type: ignore[attr-defined]
+        }
 
 
 _DEF_IGNORE_LIST = [
@@ -216,72 +209,76 @@ _DEF_IGNORE_LIST = [
 """Default list of excluded flake8 rules for the pre-commit check (additional to .flake8)."""
 
 
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class LintConfig(_PathAttrBase):
     """Lint Config."""
 
-    path_flake8: Union[Path, str] = field(validator=type_validator(), default=Path('.flake8'))
-    """Relative path to the flake8 configuration file. Default is ".flake8" created by calcipy_template."""
-
-    path_isort: Union[Path, str] = field(validator=type_validator(), default=Path('pyproject.toml'))
-    """Relative path to the isort configuration file. Default is "pyproject.toml" created by calcipy_template."""
-
-    ignore_errors: List[str] = field(validator=type_validator(), factory=lambda: _DEF_IGNORE_LIST)
-    """List of additional excluded flake8 rules for the pre-commit check."""
-
-    paths_py: List[Path] = field(validator=type_validator(), init=False)
+    paths_py: List[Path]
     """Paths to the Python files used when linting. Created with `find_project_files_by_suffix`."""
 
-    def __attrs_post_init__(self) -> None:
+    path_flake8: Path = Field(default=Path('.flake8'))
+    """Relative path to the flake8 configuration file. Default is ".flake8" created by calcipy_template."""
+
+    path_isort: Path = Field(default=Path('pyproject.toml'))
+    """Relative path to the isort configuration file. Default is "pyproject.toml" created by calcipy_template."""
+
+    ignore_errors: List[str] = Field(default_factory=lambda: _DEF_IGNORE_LIST)
+    """List of additional excluded flake8 rules for the pre-commit check."""
+
+    def __post_init__(self) -> None:
         """Finish initializing class attributes."""
-        super().__attrs_post_init__()
-        self.path_flake8 = _make_full_path(self.path_flake8, self.path_project)
-        self.path_isort = _make_full_path(self.path_isort, self.path_project)
-        self.paths_py = DG.meta.paths_by_suffix.get('py', [])
+        super().__post_init__()
+        self.path_flake8 = _make_full_path(self.path_flake8, path_base=self.path_project)
+        self.path_isort = _make_full_path(self.path_isort, path_base=self.path_project)
 
 
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class TestingConfig(_PathAttrBase):  # pylint: disable=too-many-instance-attributes
     """Test Config."""
 
-    pythons: List[str] = field(validator=type_validator(), factory=lambda: ['3.8', '3.9'])
-    """Python versions to test against. Default is `['3.8', '3.9']`."""
+    pythons: List[str] = Field(default_factory=lambda: ['3.8', '3.9'])
+    """Python versions to test against. Default is `['3.8', '3.9']`.
 
-    path_out: Union[Path, str] = field(validator=type_validator(), default=Path('releases/tests'))
+    NOTE: Selecting a Python lower that calcipy's minimum may cause unexpected failures
+
+    PLANNED: Consider adding a check to validate that the minimum Python is above calcipy's minimum
+
+    """
+
+    path_out: Path = Field(default=Path('releases/tests'))
     """Relative path to the report output directory. Default is `releases/tests`."""
 
-    path_tests: Union[Path, str] = field(validator=type_validator(), default=Path('tests'))
+    path_tests: Path = Field(default=Path('tests'))
     """Relative path to the tests directory. Default is `tests`."""
 
-    args_pytest: str = field(
-        validator=type_validator(),
+    args_pytest: str = Field(
         default='--exitfirst --showlocals --failed-first --new-first --verbose --doctest-modules',
     )
     """Default arguments to Pytest. In short form, the defaults are `-x -l --ff --nf -vv`."""
 
-    args_diff: str = field(validator=type_validator(), default='--fail-under=65 --compare-branch=origin/main')
+    args_diff: str = Field(default='--fail-under=80 --compare-branch=origin/main')
     """Default arguments to diff-cover."""
 
-    path_test_report: Path = field(validator=type_validator(), init=False)
+    path_test_report: ClassVar[Path]
     """Path to the self-contained test HTML report."""
 
-    path_diff_test_report: Path = field(validator=type_validator(), init=False)
+    path_diff_test_report: ClassVar[Path]
     """Path to the self-contained diff-test HTML report."""
 
-    path_diff_lint_report: Path = field(validator=type_validator(), init=False)
+    path_diff_lint_report: ClassVar[Path]
     """Path to the self-contained diff-lint HTML report."""
 
-    path_coverage_index: Path = field(validator=type_validator(), init=False)
+    path_coverage_index: ClassVar[Path]
     """Path to the coverage HTML index file within the report directory."""
 
-    path_mypy_index: Path = field(validator=type_validator(), init=False)
+    path_mypy_index: ClassVar[Path]
     """Path to the mypy HTML index file within the report directory."""
 
-    def __attrs_post_init__(self) -> None:
+    def __post_init__(self) -> None:
         """Finish initializing class attributes."""
-        super().__attrs_post_init__()
-        self.path_out = _make_full_path(self.path_out, self.path_project)
-        self.path_tests = _make_full_path(self.path_tests, self.path_project)
+        super().__post_init__()
+        self.path_out = _make_full_path(self.path_out, path_base=self.path_project)
+        self.path_tests = _make_full_path(self.path_tests, path_base=self.path_project)
         self.path_out.mkdir(exist_ok=True, parents=True)
         # Configure the paths to the report HTML and coverage HTML files
         self.path_test_report = self.path_out / 'test_report.html'
@@ -291,28 +288,28 @@ class TestingConfig(_PathAttrBase):  # pylint: disable=too-many-instance-attribu
         self.path_mypy_index = self.path_out / 'mypy_html/index.html'
 
 
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class CodeTagConfig(_PathAttrBase):
     """Code Tag Config."""
 
-    doc_sub_dir: Path = field(validator=type_validator(), default=Path('docs/docs'))
+    doc_sub_dir: Path = Field(default=Path('docs/docs'))
     """Relative path to the source documentation directory."""
 
-    code_tag_summary_filename: str = field(validator=type_validator(), default='CODE_TAG_SUMMARY.md')
+    code_tag_summary_filename: str = Field(default='CODE_TAG_SUMMARY.md')
     """Name of the code tag summary file."""
 
-    tags: List[str] = field(validator=type_validator(), factory=lambda: COMMON_CODE_TAGS)
+    tags: List[str] = Field(default_factory=lambda: COMMON_CODE_TAGS)
     """List of ordered tag names to match."""
 
-    re_raw: str = field(validator=type_validator(), default=CODE_TAG_RE)
+    re_raw: str = Field(default=CODE_TAG_RE)
     """string regular expression that contains `{tag}`."""
 
-    path_code_tag_summary: Path = field(validator=type_validator(), init=False)
+    path_code_tag_summary: ClassVar[Path]
     """Path to the code tag summary file. Uses `code_tag_summary_filename`."""
 
-    def __attrs_post_init__(self) -> None:
+    def __post_init__(self) -> None:
         """Finish initializing class attributes."""
-        super().__attrs_post_init__()
+        super().__post_init__()
         # Configure full path to the code tag summary file
         self.path_code_tag_summary = self.path_project / self.doc_sub_dir / self.code_tag_summary_filename
 
@@ -327,140 +324,177 @@ class CodeTagConfig(_PathAttrBase):
         return re.compile(self.re_raw.format(tag='|'.join(self.tags)))
 
 
-@mutable(kw_only=True)
+@dataclass(kw_only=True)
 class DocConfig(_PathAttrBase):
     """Documentation Config."""
 
-    doc_sub_dir: Path = field(validator=type_validator(), default=Path('docs/docs'))
+    paths_md: List[Path]
+    """Paths to Markdown files used when documenting. Created with `find_project_files_by_suffix`."""
+
+    doc_sub_dir: Path = Field(default=Path('docs/docs'))
     """Relative path to the source documentation directory."""
 
-    auto_doc_path: Optional[Path] = field(validator=type_validator(), default=None)
+    auto_doc_path: ClassVar[Path]
     """Auto-calculated based on `self.doc_sub_dir`."""
 
     handler_lookup: Optional[
         Dict[str, Callable[[str, Path], List[str]]]
-    ] = field(validator=type_validator(), default=None)
+    ] = Field(default=None)
     """Lookup dictionary for autoformatted sections of the project's markdown files."""
 
-    path_out: Path = field(validator=type_validator(), init=False)
+    path_out: ClassVar[Path]
     """The documentation output directory. Specified in `mkdocs.yml`."""
 
-    paths_md: List[Path] = field(validator=type_validator(), init=False)
-    """Paths to Markdown files used when documenting. Created with `find_project_files_by_suffix`."""
-
-    def __attrs_post_init__(self) -> None:
+    def __post_init__(self) -> None:
         """Finish initializing class attributes."""
-        super().__attrs_post_init__()
+        super().__post_init__()
         mkdocs_config = _read_yaml_file(self.path_project / _MKDOCS_CONFIG_NAME)
         self.path_out = Path(mkdocs_config.get('site_dir', 'releases/site'))
-        self.path_out = _make_full_path(self.path_out, self.path_project)
+        self.path_out = _make_full_path(self.path_out, path_base=self.path_project)
         self.path_out.mkdir(exist_ok=True, parents=True)
-        self.paths_md = DG.meta.paths_by_suffix.get('md', [])
         self.auto_doc_path = self.doc_sub_dir.parent / 'modules'
 
 
-@mutable(kw_only=True)
-class DoitGlobals:  # pylint: disable=too-many-instance-attributes
+class DoitGlobals(BaseModel):
     """Global Variables for doit."""
 
-    calcipy_dir: Path = field(validator=type_validator(), init=False, default=Path(__file__).resolve().parents[1])
-    """The calcipy directory (likely within `.venv`)."""
-
-    meta: PackageMeta = field(validator=type_validator(), init=False)
+    meta: PackageMeta
     """Package Meta-Information."""
 
-    lint: LintConfig = field(validator=type_validator(), init=False)
+    lint: LintConfig
     """Lint Config."""
 
-    test: TestingConfig = field(validator=type_validator(), init=False)
+    test: TestingConfig
     """Test Config."""
 
-    tags: CodeTagConfig = field(validator=type_validator(), init=False)
+    tags: CodeTagConfig
     """Documentation Config."""
 
-    doc: DocConfig = field(validator=type_validator(), init=False)
+    doc: DocConfig
     """Documentation Config."""
 
-    _is_set: bool = field(validator=type_validator(), default=False)
-    """Internal flag to check if already set."""
+    calcipy_dir: Path = Field(default=Path(__file__).resolve().parents[1])
+    """The calcipy directory (likely within `.venv`)."""
 
-    @log_fun
-    def set_paths(
-        self, *, path_project: Optional[Path] = None,
-    ) -> None:
-        """Configure `DoitGlobals` based on project directory.
 
-        Args:
-            path_project: optional project base directory Path. Defaults to the current working directory
+@beartype
+def _set_meta(path_project: Path, calcipy_config: Dict[str, Any]) -> PackageMeta:
+    """Initialize the meta submodules.
 
-        Raises:
-            RuntimeError: if `set_paths` is called twice. This can cause unexpected behavior, so if
-                absolutely necessary, set `DG._is_set = False`, then try `DG.set_paths()`
+    Args:
+        path_project: project base directory Path
+        calcipy_config: custom calcipy configuration from toml file
 
-        """
-        if self._is_set:
-            raise RuntimeError('DoitGlobals has already been configured and cannot be reconfigured')
+    """
+    ignore_patterns = calcipy_config.get('ignore_patterns', [])
+    return PackageMeta(path_project=path_project, ignore_patterns=ignore_patterns)
 
-        logger.info(f'Setting DG path: {path_project}', path_project=path_project, cwd=Path.cwd())
-        path_project = path_project or Path.cwd()
 
-        # Read the optional toml configuration
-        # > Note: could allow LintConfig/.../DocConfig kwargs to be set in toml, but may be difficult to maintain
-        data = (path_project / 'pyproject.toml').read_text()
-        calcipy_config = tomli.loads(data).get('tool', {}).get('calcipy', {})
+@beartype
+def _set_submodules(
+    meta: PackageMeta, calcipy_config: Dict[str, Any],
+) -> Dict[str, Union[LintConfig, TestingConfig, CodeTagConfig, DocConfig]]:
+    """Initialize the rest of the submodules.
 
-        self._set_meta(path_project, calcipy_config)
-        self._set_submodules(calcipy_config)
+    Args:
+        calcipy_config: custom calcipy configuration from toml file
 
-        self._is_set = True
+    Raises:
+        RuntimeError: if problems in formatting of the toml file
+
+    """
+    # Configure global options
+    section_keys = ['lint', 'test', 'code_tag', 'doc']
+    supported_keys = section_keys + ['ignore_patterns']
+    unexpected_keys = [key for key in calcipy_config if key not in supported_keys]
+    if unexpected_keys:
+        raise RuntimeError(f'Found unexpected key(s) {unexpected_keys} (i.e. not in {supported_keys})')
+
+    # Parse the Copier file for configuration information
+    doc_sub_dir = get_doc_dir(meta.path_project) / 'docs'  # Note: subdirectory is important
+    doc_sub_dir.mkdir(exist_ok=True, parents=True)
+
+    # Configure submodules
+    meta_kwargs = {'path_project': meta.path_project}
+    lint_k, test_k, code_k, doc_k = (calcipy_config.get(key, {}) for key in section_keys)
+    paths_py = meta.paths_by_suffix.get('py', [])
+    paths_md = meta.paths_by_suffix.get('md', [])
+    return {
+        'lint': LintConfig(**meta_kwargs, paths_py=paths_py, **lint_k),
+        'test': TestingConfig(**meta_kwargs, **test_k),
+        'tags': CodeTagConfig(**meta_kwargs, doc_sub_dir=doc_sub_dir, **code_k),
+        'doc': DocConfig(**meta_kwargs, paths_md=paths_md, doc_sub_dir=doc_sub_dir, **doc_k),
+    }
+
+
+@log_fun
+def create_dg(*, path_project: Path) -> DoitGlobals:
+    """Configure `DoitGlobals` based on project directory.
+
+    Args:
+        path_project: optional project base directory Path. Defaults to the current working directory
+
+    """
+    logger.info('Setting DG path: {path_project}', path_project=path_project)
+
+    # Read the optional toml configuration
+    # > Note: could allow LintConfig/.../DocConfig kwargs to be set in toml, but may be difficult to maintain
+    data = (path_project / 'pyproject.toml').read_text()
+    calcipy_config = tomli.loads(data).get('tool', {}).get('calcipy', {})
+
+    meta = _set_meta(path_project, calcipy_config)
+    kwargs = _set_submodules(meta, calcipy_config)
+    return DoitGlobals(meta=meta, **kwargs)
+
+
+class _DGContainer(BaseModel):
+    """Manage state of DoitGlobals.
+
+    Only used for unit testing.
+
+    """
+
+    key: str = Field(default='')
+    data: Dict[str, DoitGlobals] = Field(default_factory=dict)
 
     @beartype
-    def _set_meta(self, path_project: Path, calcipy_config: Dict[str, Any]) -> None:
-        """Initialize the meta submodules.
+    def set_dg(self, dg: DoitGlobals) -> None:
+        """Registers a DG instance.
 
         Args:
-            path_project: project base directory Path
-            calcipy_config: custom calcipy configuration from toml file
+            dg: Global doit 'Globals' class for management of global variables
 
         """
-        ignore_patterns = calcipy_config.get('ignore_patterns', [])
-        self.meta = PackageMeta(path_project=path_project, ignore_patterns=ignore_patterns)
+        self.key = str(uuid4())
+        self.data[self.key] = dg
 
     @beartype
-    def _set_submodules(self, calcipy_config: Dict[str, Any]) -> None:
-        """Initialize the rest of the submodules.
+    def get_dg(self) -> DoitGlobals:
+        """Retrieves the registered DG instance.
 
         Args:
-            calcipy_config: custom calcipy configuration from toml file
-
-        Raises:
-            RuntimeError: if problems in formatting of the toml file
+            dg: Global doit 'Globals' class for management of global variables
 
         """
-        # Configure global options
-        section_keys = ['lint', 'test', 'code_tag', 'doc']
-        supported_keys = section_keys + ['ignore_patterns']
-        unexpected_keys = [key for key in calcipy_config if key not in supported_keys]
-        if unexpected_keys:
-            raise RuntimeError(f'Found unexpected key(s) {unexpected_keys} (i.e. not in {supported_keys})')
-
-        # Parse the Copier file for configuration information
-        doc_sub_dir = get_doc_dir(self.meta.path_project) / 'docs'  # Note: subdirectory is important
-        doc_sub_dir.mkdir(exist_ok=True, parents=True)
-
-        # Configure submodules
-        meta_kwargs = {'path_project': self.meta.path_project}
-        lint_k, test_k, code_k, doc_k = (calcipy_config.get(key, {}) for key in section_keys)
-        self.lint = LintConfig(**meta_kwargs, **lint_k)  # type: ignore[arg-type]
-        self.test = TestingConfig(**meta_kwargs, **test_k)  # type: ignore[arg-type]
-        self.tags = CodeTagConfig(**meta_kwargs, doc_sub_dir=doc_sub_dir, **code_k)  # type: ignore[arg-type]
-        self.doc = DocConfig(**meta_kwargs, doc_sub_dir=doc_sub_dir, **doc_k)  # type: ignore[arg-type]
+        return self.data[self.key]
 
 
-DG = DoitGlobals()
-"""Global doit Globals class used to manage global variables."""
+_DG_CONTAINER = _DGContainer()
+"""Single instance."""
 
-_WORK_DIR = doit.get_initial_workdir()
-"""Work directory identified by doit."""
+set_dg = _DG_CONTAINER.set_dg
+get_dg = _DG_CONTAINER.get_dg
+"""Alias for exported function."""
 
-DG.set_paths(path_project=(Path(_WORK_DIR) if _WORK_DIR else Path.cwd()).resolve())
+
+@beartype
+def init_dg():
+    """Initialize the global DG instance."""
+    work_dir = doit.get_initial_workdir()
+    path_project = (Path(work_dir) if work_dir else Path.cwd()).resolve()
+    dg = create_dg(path_project=path_project)
+    set_dg(dg)
+
+
+# Eagerly initialize at least one global DG instance
+init_dg()
