@@ -3,23 +3,21 @@
 import json
 from pathlib import Path
 
-import attrs
+import arrow
 import numpy as np
-import pendulum
 import requests
 import tomli
-from attrs import field, mutable
-from attrs_strict import type_validator
+from arrow import Arrow
 from beartype import beartype
-from beartype.typing import Dict, List, Optional
+from beartype.typing import Dict, List, Optional, Union
 from bidict import bidict
 from doit.tools import Interactive
 from loguru import logger
-from pendulum import DateTime
+from pydantic import BaseModel, Field
 from pyrate_limiter import Duration, Limiter, RequestRate
 
 from .base import debug_task
-from .doit_globals import DG, DoitTask
+from .doit_globals import DoitTask, get_dg
 
 # ----------------------------------------------------------------------------------------------------------------------
 # Publish releases
@@ -48,9 +46,10 @@ def task_lock() -> DoitTask:
         DoitTask: doit task
 
     """
+    dg = get_dg()
     task = debug_task(['poetry lock --no-update'])
-    task['file_dep'].append(DG.meta.path_toml)
-    task['targets'].extend([DG.meta.path_project / 'poetry.lock'])
+    task['file_dep'].append(dg.meta.path_toml)
+    task['targets'].extend([dg.meta.path_project / 'poetry.lock'])
     return task
 
 
@@ -65,7 +64,6 @@ def _publish_task(publish_args: str = '') -> DoitTask:
         DoitTask: doit task
 
     """
-    # FIXME: Pyroma doesn't have the poetry requirement it needs...
     return debug_task([
         Interactive('poetry run nox --session build_dist build_check'),
         f'poetry publish {publish_args}',
@@ -101,47 +99,48 @@ def task_publish_test_pypi() -> DoitTask:
 # Check for stale packages
 
 
-def _auto_convert(_cls, fields):  # type: ignore # noqa: ANN001, ANN202, CCR001
-    """Auto convert datetime attributes from string.
+class ArrowType(Arrow):
+    """Create a type for pydantic use of Arrow."""
 
-    Based on: https://www.attrs.org/en/stable/extending.html#automatic-field-transformation-and-modification
+    @classmethod
+    def __get_validators__(cls):
+        yield cls.validate
 
-    Args:
-        _cls: unused class argument
-        fields: `_HostedPythonPackageAttribtues`
+    @classmethod
+    def validate(cls, value):
+        @beartype
+        def arrow_converter(date: Optional[Union[str, Arrow]]) -> Optional[Arrow]:
+            return arrow.get(date) if date else date
 
-    Returns:
-        results
-
-    """
-    results = []
-    for fld in fields:
-        if fld.converter is not None:  # pragma: no cover
-            results.append(fld)
-            continue
-
-        converter: Optional[DateTime] = None
-        if fld.type in {Optional[DateTime], DateTime, 'datetime'}:
-            converter = (lambda d: pendulum.parse(d) if isinstance(d, str) else d)
-        results.append(fld.evolve(converter=converter))
-
-    return results
+        return arrow_converter(value)
 
 
-@mutable(kw_only=True, field_transformer=_auto_convert)
-class _HostedPythonPackage():
+class _HostedPythonPackage(BaseModel):
     """Representative information for a python package hosted on some domain."""
 
     # Note: "releases" was removed from the versioned URL: https://warehouse.pypa.io/api-reference/json.html#release
-    domain: str = field(validator=type_validator(), default='https://pypi.org/pypi/{name}/json')
-    name: str = field(validator=type_validator())
-    version: str = field(validator=type_validator())
-    datetime: Optional[DateTime] = field(validator=type_validator(), default=None)
-    latest_version: str = field(validator=type_validator(), default='')
-    latest_datetime: Optional[DateTime] = field(validator=type_validator(), default=None)
+    domain: str = Field(default='https://pypi.org/pypi/{name}/json')
+    name: str
+    version: str
+    datetime: Optional[ArrowType] = Field(default=None)
+    latest_version: str = Field(default='')
+    latest_datetime: Optional[ArrowType] = Field(default=None)
+
+    # HACK: See pending pydantic changes: https://github.com/pydantic/pydantic/discussions/4456
+    def _iter(self, *args, **kwargs):
+        """Hack to serialize Arrow types.
+
+        Based on: https://github.com/pydantic/pydantic/issues/2277#issuecomment-764132528
+
+        """
+        for key, v in super()._iter(*args, **kwargs):
+            if 'datetime' in key:
+                yield key, str(v)
+            else:
+                yield key, v
 
 
-_PATH_PACK_LOCK = DG.meta.path_project / '.calcipy_packaging.lock'
+_PATH_PACK_LOCK = get_dg().meta.path_project / '.calcipy_packaging.lock'
 """Path to the packaging lock file."""
 
 # HACK: Check that this works then refactor (shouldn't be global)
@@ -175,7 +174,7 @@ def _get_release_date(package: _HostedPythonPackage) -> _HostedPythonPackage:
 
     # Also retrieve the latest release date of the package looking through all releases
     release_dates = bidict({
-        pendulum.parse(release_data[0]['upload_time_iso_8601']): version
+        arrow.get(release_data[0]['upload_time_iso_8601']): version
         for version, release_data in releases.items()
         if release_data
     })
@@ -249,10 +248,7 @@ def _write_cache(updated_packages: List[_HostedPythonPackage], path_pack_lock: P
         path_pack_lock: Path to the lock file. Default is `_PATH_PACK_LOCK`
 
     """
-    def serialize(_inst, _field, value):  # noqa: ANN001, ANN201
-        return value.to_iso8601_string() if isinstance(value, DateTime) else value
-
-    new_cache = {pack.name: attrs.asdict(pack, value_serializer=serialize) for pack in updated_packages}
+    new_cache = {pack.name: json.loads(pack.json()) for pack in updated_packages}
     pretty_json = json.dumps(new_cache, indent=4, separators=(',', ': '), sort_keys=True)
     path_pack_lock.write_text(pretty_json + '\n')
 
@@ -294,32 +290,35 @@ def _check_for_stale_packages(packages: List[_HostedPythonPackage], *, stale_mon
 
     """
     def format_package(pack: _HostedPythonPackage) -> str:
-        delta = f'{now.diff(pack.datetime).in_months()} months ago:'
+        delta = pack.datetime.humanize()
         latest = '' if pack.version == pack.latest_version else f' (*New version available: {pack.latest_version}*)'
-        return f'- {delta} {pack.name} {pack.version}{latest}'
+        return f'- {delta}: {pack.name} {pack.version}{latest}'
 
-    now = pendulum.now()
-    stale_cutoff = now.subtract(months=stale_months)
+    now = arrow.utcnow()
+    stale_cutoff = now.shift(months=-1 * stale_months)
     stale_packages = [pack for pack in packages if pack.datetime < stale_cutoff]
     if stale_packages:
         stale_list = '\n'.join(map(format_package, sorted(stale_packages, key=lambda x: x.datetime)))
         logger.warning(f'Found stale packages that may be a dependency risk:\n\n{stale_list}\n\n')
     else:
-        max_months = np.amax([now.diff(pack.datetime).in_months() for pack in packages])
-        logger.warning(f'The oldest package was released {max_months} months ago (stale is >{stale_months} months)\n')
+        oldest_date = np.amin([pack.datetime for pack in packages])
+        logger.warning(f'The oldest package was released {oldest_date.humanize()} (stale is >{stale_months} months)\n')
+
+
+_DEF_STALE_M = 48
 
 
 @beartype
 def find_stale_packages(
     path_lock: Path, path_pack_lock: Path = _PATH_PACK_LOCK,
-    *, stale_months: int = 48,
+    *, stale_months: int = _DEF_STALE_M,
 ) -> None:
     """Read the cached packaging information.
 
     Args:
         path_lock: Path to the lock file to parse
         path_pack_lock: Path to the lock file. Default is `_PATH_PACK_LOCK`
-        stale_months: cutoff in months for when a package might be stale enough to be a risk. Default is 48
+        stale_months: cutoff in months for when a package might be stale enough to be a risk. Default is _DEF_STALE_M
 
     """
     packages = _read_packages(path_lock)
@@ -337,10 +336,10 @@ def task_check_for_stale_packages() -> DoitTask:
         DoitTask: doit task
 
     """
-    path_lock = DG.meta.path_project / 'poetry.lock'
+    path_lock = get_dg().meta.path_project / 'poetry.lock'
     path_pack_lock = _PATH_PACK_LOCK
     task = debug_task([
-        (find_stale_packages, (path_lock, path_pack_lock), {'stale_months': 48}),
+        (find_stale_packages, (path_lock, path_pack_lock), {'stale_months': _DEF_STALE_M}),
         Interactive('poetry run pip-check --cmd="poetry run pip" --hide-unchanged'),
     ])
     task['file_dep'].append(path_lock)
