@@ -7,12 +7,11 @@ https://groups.google.com/g/python-doit/c/SgoiGt_XYDU/m/PQ8JmlKFAgAJ
 
 from enum import IntEnum
 
-from attrs import field, mutable
-from attrs_strict import type_validator
 from beartype import beartype
 from beartype.typing import Any, List, OrderedDict
 from doit.reporter import ConsoleReporter
 from doit.task import Task
+from pydantic import BaseModel
 from sty import fg
 
 
@@ -26,12 +25,11 @@ class _TaskExitCode(IntEnum):
     SKIP_UP_TO_DATE = 4
 
 
-@mutable(kw_only=True)
-class _TaskSummary:
+class _TaskSummary(BaseModel):
     """Task Summary."""
 
-    name: str = field(validator=type_validator())
-    exit_code: _TaskExitCode = field(validator=type_validator())
+    name: str
+    exit_code: _TaskExitCode
 
 
 @beartype
